@@ -1286,7 +1286,7 @@ class ProjectTestCase(BaseExecutionsTestCase):
         pm_yaml['sync_on_run'] = True
         # templates
         pm_yaml['templates'] = test_yaml_templates
-        pm_yaml['templates_rewrite'] = False
+        pm_yaml['templates_rewrite'] = True
         # fast task widget
         pm_yaml['view'] = test_yaml_view
         # Prepare repo
@@ -1803,7 +1803,7 @@ class ProjectTestCase(BaseExecutionsTestCase):
             for i in indexes:
                 self.assertEqual(
                     results[i]['status'], status,
-                    msg='Bulk index: {}, Response status: `{}`!=`{}`, Response data:'.format(
+                    msg='Bulk index: {}, Response status: `{}`!=`{}`, Response data: {}'.format(
                         i, results[i]['status'], status, results[i]['data']
                     )
                 )
